(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[92101],{65262:()=>{Prism.languages.hpkp={directive:{pattern:/\b(?:includeSubDomains|max-age|pin-sha256|preload|report-to|report-uri|strict)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}}]);
//# sourceMappingURL=prism-lang.prism-hpkp-min.b458562b.chunk.js.map