(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[3108],{69468:()=>{Prism.languages["t4-vb"]=Prism.languages["t4-templating"].createT4("vbnet")}}]);
//# sourceMappingURL=prism-lang.prism-t4-vb.c2b3c9cc.chunk.js.map