(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[42605],{86827:()=>{Prism.languages.git={comment:/^#.*/m,deleted:/^[-\u2013].*/m,inserted:/^\+.*/m,string:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,command:{pattern:/^.*\$ git .*$/m,inside:{parameter:/\s--?\w+/}},coord:/^@@.*@@$/m,"commit-sha1":/^commit \w{40}$/m}}}]);
//# sourceMappingURL=prism-lang.prism-git.ce336a64.chunk.js.map