(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[39615],{88430:()=>{Prism.languages["t4-vb"]=Prism.languages["t4-templating"].createT4("vbnet")}}]);
//# sourceMappingURL=prism-lang.prism-t4-vb-min.7c9fbd5c.chunk.js.map