(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[67055],{24352:()=>{!function(e){var n=e.languages.javascript["template-string"],t=n.pattern.source,r=n.inside.interpolation,a=r.inside["interpolation-punctuation"],i=r.pattern.source;function s(n,r){if(e.languages[n])return{pattern:RegExp("((?:"+r+")\\s*)"+t),lookbehind:!0,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},"embedded-code":{pattern:/[\s\S]+/,alias:n}}}}function o(e,n){return"___"+n.toUpperCase()+"_"+e+"___"}function p(n,t,r){var a={code:n,grammar:t,language:r};return e.hooks.run("before-tokenize",a),a.tokens=e.tokenize(a.code,a.grammar),e.hooks.run("after-tokenize",a),a.tokens}function l(n){var t={};t["interpolation-punctuation"]=a;var i=e.tokenize(n,t);if(3===i.length){var s=[1,1];s.push.apply(s,p(i[1],e.languages.javascript,"javascript")),i.splice.apply(i,s)}return new e.Token("interpolation",i,r.alias,n)}function g(n,t,r){var a=e.tokenize(n,{interpolation:{pattern:RegExp(i),lookbehind:!0}}),s=0,g={},u=p(a.map((function(e){if("string"==typeof e)return e;for(var t,a=e.content;-1!==n.indexOf(t=o(s++,r)););return g[t]=a,t})).join(""),t,r),f=Object.keys(g);return s=0,function e(n){for(var t=0;t<n.length;t++){if(s>=f.length)return;var r=n[t];if("string"==typeof r||"string"==typeof r.content){var a=f[s],i="string"==typeof r?r:r.content,o=i.indexOf(a);if(-1!==o){++s;var p=i.substring(0,o),u=l(g[a]),c=i.substring(o+a.length),y=[];if(p&&y.push(p),y.push(u),c){var v=[c];e(v),y.push.apply(y,v)}"string"==typeof r?(n.splice.apply(n,[t,1].concat(y)),t+=y.length-1):r.content=y}}else{var d=r.content;Array.isArray(d)?e(d):e([d])}}}(u),new e.Token(r,u,"language-"+r,n)}e.languages.javascript["template-string"]=[s("css","\\b(?:styled(?:\\([^)]*\\))?(?:\\s*\\.\\s*\\w+(?:\\([^)]*\\))*)*|css(?:\\s*\\.\\s*(?:global|resolve))?|createGlobalStyle|keyframes)"),s("html","\\bhtml|\\.\\s*(?:inner|outer)HTML\\s*\\+?="),s("svg","\\bsvg"),s("markdown","\\b(?:markdown|md)"),s("graphql","\\b(?:gql|graphql(?:\\s*\\.\\s*experimental)?)"),s("sql","\\bsql"),n].filter(Boolean);var u={javascript:!0,js:!0,typescript:!0,ts:!0,jsx:!0,tsx:!0};function f(e){return"string"==typeof e?e:Array.isArray(e)?e.map(f).join(""):f(e.content)}e.hooks.add("after-tokenize",(function(n){n.language in u&&function n(t){for(var r=0,a=t.length;r<a;r++){var i=t[r];if("string"!=typeof i){var s=i.content;if(Array.isArray(s))if("template-string"===i.type){var o=s[1];if(3===s.length&&"string"!=typeof o&&"embedded-code"===o.type){var p=f(o),l=o.alias,u=Array.isArray(l)?l[0]:l,c=e.languages[u];if(!c)continue;s[1]=g(p,c,u)}}else n(s);else"string"!=typeof s&&n([s])}}}(n.tokens)}))}(Prism)}}]);
//# sourceMappingURL=prism-lang.prism-js-templates-min.25bd69c7.chunk.js.map