(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[75454],{73994:()=>{!function(n){var e=n.util.clone(n.languages.javascript),t=/(?:\s|\/\/.*(?!.)|\/\*(?:[^*]|\*(?!\/))\*\/)/.source,a=/(?:\{(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])*\})/.source,s=/(?:\{<S>*\.{3}(?:[^{}]|<BRACES>)*\})/.source;function g(n,e){return n=n.replace(/<S>/g,(function(){return t})).replace(/<BRACES>/g,(function(){return a})).replace(/<SPREAD>/g,(function(){return s})),RegExp(n,e)}s=g(s).source,n.languages.jsx=n.languages.extend("markup",e),n.languages.jsx.tag.pattern=g(/<\/?(?:[\w.:-]+(?:<S>+(?:[\w.:$-]+(?:=(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s{'"/>=]+|<BRACES>))?|<SPREAD>))*<S>*\/?)?>/.source),n.languages.jsx.tag.inside.tag.pattern=/^<\/?[^\s>\/]*/,n.languages.jsx.tag.inside["attr-value"].pattern=/=(?!\{)(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s'">]+)/,n.languages.jsx.tag.inside.tag.inside["class-name"]=/^[A-Z]\w*(?:\.[A-Z]\w*)*$/,n.languages.jsx.tag.inside.comment=e.comment,n.languages.insertBefore("inside","attr-name",{spread:{pattern:g(/<SPREAD>/.source),inside:n.languages.jsx}},n.languages.jsx.tag),n.languages.insertBefore("inside","special-attr",{script:{pattern:g(/=<BRACES>/.source),alias:"language-javascript",inside:{"script-punctuation":{pattern:/^=(?=\{)/,alias:"punctuation"},rest:n.languages.jsx}}},n.languages.jsx.tag);var o=function(n){return n?"string"===typeof n?n:"string"===typeof n.content?n.content:n.content.map(o).join(""):""},r=function(e){for(var t=[],a=0;a<e.length;a++){var s=e[a],g=!1;if("string"!==typeof s&&("tag"===s.type&&s.content[0]&&"tag"===s.content[0].type?"</"===s.content[0].content[0].content?t.length>0&&t[t.length-1].tagName===o(s.content[0].content[1])&&t.pop():"/>"===s.content[s.content.length-1].content||t.push({tagName:o(s.content[0].content[1]),openedBraces:0}):t.length>0&&"punctuation"===s.type&&"{"===s.content?t[t.length-1].openedBraces++:t.length>0&&t[t.length-1].openedBraces>0&&"punctuation"===s.type&&"}"===s.content?t[t.length-1].openedBraces--:g=!0),(g||"string"===typeof s)&&t.length>0&&0===t[t.length-1].openedBraces){var c=o(s);a<e.length-1&&("string"===typeof e[a+1]||"plain-text"===e[a+1].type)&&(c+=o(e[a+1]),e.splice(a+1,1)),a>0&&("string"===typeof e[a-1]||"plain-text"===e[a-1].type)&&(c=o(e[a-1])+c,e.splice(a-1,1),a--),e[a]=new n.Token("plain-text",c,null,c)}s.content&&"string"!==typeof s.content&&r(s.content)}};n.hooks.add("after-tokenize",(function(n){"jsx"!==n.language&&"tsx"!==n.language||r(n.tokens)}))}(Prism)}}]);
//# sourceMappingURL=prism-lang.prism-jsx.24c9a5ea.chunk.js.map