(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[8904],{95515:()=>{!function(e){function n(e,n){return"___"+e.toUpperCase()+n+"___"}Object.defineProperties(e.languages["markup-templating"]={},{buildPlaceholders:{value:function(t,a,r,o){if(t.language===a){var c=t.tokenStack=[];t.code=t.code.replace(r,(function(e){if("function"==typeof o&&!o(e))return e;for(var r,u=c.length;-1!==t.code.indexOf(r=n(a,u));)++u;return c[u]=e,r})),t.grammar=e.languages.markup}}},tokenizePlaceholders:{value:function(t,a){if(t.language===a&&t.tokenStack){t.grammar=e.languages[a];var r=0,o=Object.keys(t.tokenStack);!function c(u){for(var i=0;i<u.length&&!(r>=o.length);i++){var f=u[i];if("string"==typeof f||f.content&&"string"==typeof f.content){var g=o[r],l=t.tokenStack[g],s="string"==typeof f?f:f.content,p=n(a,g),k=s.indexOf(p);if(k>-1){++r;var h=s.substring(0,k),d=new e.Token(a,e.tokenize(l,t.grammar),"language-"+a,l),m=s.substring(k+p.length),v=[];h&&v.push.apply(v,c([h])),v.push(d),m&&v.push.apply(v,c([m])),"string"==typeof f?u.splice.apply(u,[i,1].concat(v)):f.content=v}}else f.content&&c(f.content)}return u}(t.tokens)}}}})}(Prism)}}]);
//# sourceMappingURL=prism-lang.prism-markup-templating-min.2e1499ac.chunk.js.map