(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[69174],{35628:()=>{Prism.languages.arff={comment:/%.*/,string:{pattern:/(["'])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:/@(?:attribute|data|end|relation)\b/i,number:/\b\d+(?:\.\d+)?\b/,punctuation:/[{},]/}}}]);
//# sourceMappingURL=prism-lang.prism-arff.4ebfcacb.chunk.js.map