(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[36923],{59497:()=>{Prism.languages.cilkcpp=Prism.languages.insertBefore("cpp","function",{"parallel-keyword":{pattern:/\bcilk_(?:for|reducer|s(?:cope|pawn|ync))\b/,alias:"keyword"}}),Prism.languages["cilk-cpp"]=Prism.languages.cilkcpp,Prism.languages.cilk=Prism.languages.cilkcpp}}]);
//# sourceMappingURL=prism-lang.prism-cilkcpp.2845fa02.chunk.js.map