(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[96663],{61981:()=>{Prism.languages.jsonp=Prism.languages.extend("json",{punctuation:/[{}[\]();,.]/}),Prism.languages.insertBefore("jsonp","punctuation",{function:/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*\()/})}}]);
//# sourceMappingURL=prism-lang.prism-jsonp.f17fc6cc.chunk.js.map