(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[4920],{62811:()=>{Prism.languages.cilkc=Prism.languages.insertBefore("c","function",{"parallel-keyword":{pattern:/\bcilk_(?:for|reducer|s(?:cope|pawn|ync))\b/,alias:"keyword"}}),Prism.languages["cilk-c"]=Prism.languages.cilkc}}]);
//# sourceMappingURL=prism-lang.prism-cilkc-min.3cba448d.chunk.js.map