(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[18403],{57482:()=>{Prism.languages.brainfuck={pointer:{pattern:/<|>/,alias:"keyword"},increment:{pattern:/\+/,alias:"inserted"},decrement:{pattern:/-/,alias:"deleted"},branching:{pattern:/\[|\]/,alias:"important"},operator:/[.,]/,comment:/\S+/}}}]);
//# sourceMappingURL=prism-lang.prism-brainfuck-min.cb567b27.chunk.js.map