(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[79532],{6233:()=>{Prism.languages.hsts={directive:{pattern:/\b(?:includeSubDomains|max-age|preload)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}}]);
//# sourceMappingURL=prism-lang.prism-hsts-min.2ae1e1de.chunk.js.map