(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[31697],{76147:()=>{Prism.languages.csv={value:/[^\r\n,"]+|"(?:[^"]|"")*"(?!")/,punctuation:/,/}}}]);
//# sourceMappingURL=prism-lang.prism-csv.106521a9.chunk.js.map