.debug-container .ant-card-body{overflow:auto}.debug-container .ant-table-wrapper{width:100%}.debug-container .ant-table-cell{white-space:nowrap}.debug-container .ant-table-tbody td:first-child,.debug-container .ant-table-thead th:first-child{max-width:none;min-width:200px}.debug-card{background-color:#fff;border:1px solid #e8e8e8}.debug-card pre{background-color:#f6f8fa;border:1px solid #e1e8e8;border-radius:6px;overflow:auto;padding:16px}.debug-card code{color:#24292e}.dark .debug-card{background-color:#141414;border-color:#303030;color:#fff}.dark .debug-container .ant-card-head{background-color:#1f1f1f;border-bottom-color:#303030;color:#fff}.dark .debug-container .ant-table{background-color:#141414;color:#fff}.dark .debug-container .ant-table-thead>tr>th{background-color:#1f1f1f;border-bottom:1px solid #303030;color:#fff}.dark .debug-container .ant-table-tbody>tr>td{border-bottom:1px solid #303030;color:#fff}.dark .debug-container .ant-table-tbody>tr:hover>td{background-color:#1f1f1f}.dark .debug-container .ant-tabs-content,.dark .debug-container .ant-tabs-tab{color:#fff}.dark .debug-card pre{background-color:#1f1f1f;border-color:#303030;color:#fff}.dark .debug-card code{color:#e6e6e6}.debug-container .status-success{color:#52c41a}.debug-container .status-failed{color:#ff4d4f}.debug-container .status-pending{color:#1890ff}.dark .debug-container .status-success{color:#73d13d}
/*# sourceMappingURL=40036.f1973587.chunk.css.map*/