(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[97908],{65070:()=>{!function(e){var n=e.languages.javascript["template-string"],t=n.pattern.source,r=n.inside.interpolation,a=r.inside["interpolation-punctuation"],s=r.pattern.source;function o(n,r){if(e.languages[n])return{pattern:RegExp("((?:"+r+")\\s*)"+t),lookbehind:!0,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},"embedded-code":{pattern:/[\s\S]+/,alias:n}}}}function i(e,n){return"___"+n.toUpperCase()+"_"+e+"___"}function p(n,t,r){var a={code:n,grammar:t,language:r};return e.hooks.run("before-tokenize",a),a.tokens=e.tokenize(a.code,a.grammar),e.hooks.run("after-tokenize",a),a.tokens}function l(n){var t={};t["interpolation-punctuation"]=a;var s=e.tokenize(n,t);if(3===s.length){var o=[1,1];o.push.apply(o,p(s[1],e.languages.javascript,"javascript")),s.splice.apply(s,o)}return new e.Token("interpolation",s,r.alias,n)}function u(n,t,r){var a=e.tokenize(n,{interpolation:{pattern:RegExp(s),lookbehind:!0}}),o=0,u={},c=p(a.map((function(e){if("string"===typeof e)return e;for(var t,a=e.content;-1!==n.indexOf(t=i(o++,r)););return u[t]=a,t})).join(""),t,r),g=Object.keys(u);return o=0,function e(n){for(var t=0;t<n.length;t++){if(o>=g.length)return;var r=n[t];if("string"===typeof r||"string"===typeof r.content){var a=g[o],s="string"===typeof r?r:r.content,i=s.indexOf(a);if(-1!==i){++o;var p=s.substring(0,i),c=l(u[a]),f=s.substring(i+a.length),y=[];if(p&&y.push(p),y.push(c),f){var v=[f];e(v),y.push.apply(y,v)}"string"===typeof r?(n.splice.apply(n,[t,1].concat(y)),t+=y.length-1):r.content=y}}else{var d=r.content;Array.isArray(d)?e(d):e([d])}}}(c),new e.Token(r,c,"language-"+r,n)}e.languages.javascript["template-string"]=[o("css",/\b(?:styled(?:\([^)]*\))?(?:\s*\.\s*\w+(?:\([^)]*\))*)*|css(?:\s*\.\s*(?:global|resolve))?|createGlobalStyle|keyframes)/.source),o("html",/\bhtml|\.\s*(?:inner|outer)HTML\s*\+?=/.source),o("svg",/\bsvg/.source),o("markdown",/\b(?:markdown|md)/.source),o("graphql",/\b(?:gql|graphql(?:\s*\.\s*experimental)?)/.source),o("sql",/\bsql/.source),n].filter(Boolean);var c={javascript:!0,js:!0,typescript:!0,ts:!0,jsx:!0,tsx:!0};function g(e){return"string"===typeof e?e:Array.isArray(e)?e.map(g).join(""):g(e.content)}e.hooks.add("after-tokenize",(function(n){n.language in c&&function n(t){for(var r=0,a=t.length;r<a;r++){var s=t[r];if("string"!==typeof s){var o=s.content;if(Array.isArray(o))if("template-string"===s.type){var i=o[1];if(3===o.length&&"string"!==typeof i&&"embedded-code"===i.type){var p=g(i),l=i.alias,c=Array.isArray(l)?l[0]:l,f=e.languages[c];if(!f)continue;o[1]=u(p,f,c)}}else n(o);else"string"!==typeof o&&n([o])}}}(n.tokens)}))}(Prism)}}]);
//# sourceMappingURL=prism-lang.prism-js-templates.7df73cbc.chunk.js.map