(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[58967],{2594:()=>{!function(e){var a=e.util.clone(e.languages.typescript);e.languages.tsx=e.languages.extend("jsx",a),delete e.languages.tsx.parameter,delete e.languages.tsx["literal-property"];var t=e.languages.tsx.tag;t.pattern=RegExp("(^|[^\\w$]|(?=</))(?:"+t.pattern.source+")",t.pattern.flags),t.lookbehind=!0}(Prism)}}]);
//# sourceMappingURL=prism-lang.prism-tsx-min.df8f5052.chunk.js.map