(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[76402],{13165:()=>{Prism.languages.csv={value:/[^\r\n,"]+|"(?:[^"]|"")*"(?!")/,punctuation:/,/}}}]);
//# sourceMappingURL=prism-lang.prism-csv-min.9f92b0a3.chunk.js.map