(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[28703],{14129:()=>{!function(e){function n(n,a){e.languages[n]&&e.languages.insertBefore(n,"comment",{"doc-comment":a})}var a=e.languages.markup.tag,t={pattern:/\/\/\/.*/,greedy:!0,alias:"comment",inside:{tag:a}},s={pattern:/'''.*/,greedy:!0,alias:"comment",inside:{tag:a}};n("csharp",t),n("fsharp",t),n("vbnet",s)}(Prism)}}]);
//# sourceMappingURL=prism-lang.prism-xml-doc.aec98047.chunk.js.map