code[class*=language-],pre[class*=language-]{word-wrap:normal;background:none;color:#000;font-family:Consolas,Monaco,Andale Mono,Ubuntu Mono,monospace;font-size:1em;-webkit-hyphens:none;hyphens:none;line-height:1.5;tab-size:4;text-align:left;text-shadow:0 1px #fff;white-space:pre;word-break:normal;word-spacing:normal}code[class*=language-] ::selection,code[class*=language-]::selection,pre[class*=language-] ::selection,pre[class*=language-]::selection{background:#b3d4fc;text-shadow:none}@media print{code[class*=language-],pre[class*=language-]{text-shadow:none}}pre[class*=language-]{margin:.5em 0;overflow:auto;padding:1em}:not(pre)>code[class*=language-],pre[class*=language-]{background:#f5f2f0}:not(pre)>code[class*=language-]{border-radius:.3em;padding:.1em;white-space:normal}.token.cdata,.token.comment,.token.doctype,.token.prolog{color:#708090}.token.punctuation{color:#999}.token.namespace{opacity:.7}.token.boolean,.token.constant,.token.deleted,.token.number,.token.property,.token.symbol,.token.tag{color:#905}.token.attr-name,.token.builtin,.token.char,.token.inserted,.token.selector,.token.string{color:#690}.language-css .token.string,.style .token.string,.token.entity,.token.operator,.token.url{background:#ffffff80;color:#9a6e3a}.token.atrule,.token.attr-value,.token.keyword{color:#07a}.token.class-name,.token.function{color:#dd4a68}.token.important,.token.regex,.token.variable{color:#e90}.token.bold,.token.important{font-weight:700}.token.italic{font-style:italic}.token.entity{cursor:help}.debug-container .ant-card-body{overflow:auto}.debug-container .ant-table-wrapper{width:100%}.debug-container .ant-table-cell{white-space:nowrap}.debug-container .ant-table-tbody td:first-child,.debug-container .ant-table-thead th:first-child{max-width:none;min-width:200px}.debug-card{background-color:#fff;border:1px solid #e8e8e8}.debug-card pre{background-color:#f6f8fa;border:1px solid #e1e8e8;border-radius:6px;overflow:auto;padding:16px}.debug-card code{color:#24292e}.dark .debug-card{background-color:#141414;border-color:#303030;color:#fff}.dark .debug-container .ant-card-head{background-color:#1f1f1f;border-bottom-color:#303030;color:#fff}.dark .debug-container .ant-table{background-color:#141414;color:#fff}.dark .debug-container .ant-table-thead>tr>th{background-color:#1f1f1f;border-bottom:1px solid #303030;color:#fff}.dark .debug-container .ant-table-tbody>tr>td{border-bottom:1px solid #303030;color:#fff}.dark .debug-container .ant-table-tbody>tr:hover>td{background-color:#1f1f1f}.dark .debug-container .ant-tabs-content,.dark .debug-container .ant-tabs-tab{color:#fff}.dark .debug-card pre{background-color:#1f1f1f;border-color:#303030;color:#fff}.dark .debug-card code{color:#e6e6e6}.debug-container .status-success{color:#52c41a}.debug-container .status-failed{color:#ff4d4f}.debug-container .status-pending{color:#1890ff}.dark .debug-container .status-success{color:#73d13d}
/*# sourceMappingURL=99948.485ec235.chunk.css.map*/