(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[62006],{78274:()=>{Prism.languages.t4=Prism.languages["t4-cs"]=Prism.languages["t4-templating"].createT4("csharp")}}]);
//# sourceMappingURL=prism-lang.prism-t4-cs.62d00e56.chunk.js.map