(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[84367],{68503:()=>{Prism.languages.hsts={directive:{pattern:/\b(?:includeSubDomains|max-age|preload)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}}]);
//# sourceMappingURL=prism-lang.prism-hsts.ad2de606.chunk.js.map