(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[31894],{47497:()=>{Prism.languages.gcode={comment:/;.*|\B\(.*?\)\B/,string:{pattern:/"(?:""|[^"])*"/,greedy:!0},keyword:/\b[GM]\d+(?:\.\d+)?\b/,property:/\b[A-Z]/,checksum:{pattern:/(\*)\d+/,lookbehind:!0,alias:"number"},punctuation:/[:*]/}}}]);
//# sourceMappingURL=prism-lang.prism-gcode-min.e8d37109.chunk.js.map