(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[37156],{292:()=>{Prism.languages["nand2tetris-hdl"]={comment:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,keyword:/\b(?:BUILTIN|CHIP|CLOCKED|IN|OUT|PARTS)\b/,boolean:/\b(?:false|true)\b/,function:/\b[A-Za-z][A-Za-z0-9]*(?=\()/,number:/\b\d+\b/,operator:/=|\.\./,punctuation:/[{}[\];(),:]/}}}]);
//# sourceMappingURL=prism-lang.prism-nand2tetris-hdl.3ec27498.chunk.js.map