(self.webpackChunkfrontend=self.webpackChunkfrontend||[]).push([[4198],{70467:()=>{var n;(n=Prism).languages.ignore={comment:/^#.*/m,entry:{pattern:/\S(?:.*(?:(?:\\ )|\S))?/,alias:"string",inside:{operator:/^!|\*\*?|\?/,regex:{pattern:/(^|[^\\])\[[^\[\]]*\]/,lookbehind:!0},punctuation:/\//}}},n.languages.gitignore=n.languages.ignore,n.languages.hgignore=n.languages.ignore,n.languages.npmignore=n.languages.ignore}}]);
//# sourceMappingURL=prism-lang.prism-ignore-min.d3a41156.chunk.js.map